mccloud
==============

    Author: Ken Jenney

This script was created to support management of an AWS VPC

Installation Instructions
------------------------

.. code:: bash

    $ pip install mccloud

Executing
---------

Once installed run ``mccloud`` CLI with ``--help`` option:

.. code:: bash

    $ mccloud --help

